@@ -362,13 +362,29 @@ class RegistrationClient:
 
         _logger.info(session['url'] + ' ')
         # at this point the session has been created. If create only, exit
-        if not file_list:
-            return session
+        if file_list: #
+            self.register_datasets()
+
+        return session
+
+    def register_files(self, filelist):
         F = []  # empty list whose keys will be relative paths and content filenames
         md5s = []
         file_sizes = []
 
         for fn in self.find_files(ses_path) if file_list is True else file_list:
+            if fn.suffix in EXCLUDED_EXTENSIONS:
+                _logger.debug('Excluded: ', str(fn))
+                continue
+            if not _check_filename_for_registration(fn, self.registration_patterns):
+                _logger.warning('No matching dataset type for: ' + str(fn))
+                continue
+            if fn.suffix not in self.file_extensions:
+                _logger.warning('No matching dataformat (ie. file extension) for: ' + str(fn))
+                continue
+            if not _register_bool(fn.name, file_list):
+                _logger.debug('Not in filelist: ' + str(fn))
+                continue
             try:
                 assert (str(gen_rel_path) in str(fn))
             except AssertionError as e:
@@ -391,7 +407,6 @@ class RegistrationClient:
               'versions': [version.ibllib() for _ in F]
               }
         self.one.alyx.post('/register-file', data=r_)
-        return session
 
     def register_water_administration(self, subject, volume, **kwargs):
         """
